pub struct Forests<T>{ /* private fields */ }Expand description
Data structure for building disjoint sets
Implementations
Sourceimpl<T> Forests<T>
impl<T> Forests<T>
pub fn new() -> Self
Sourcepub fn count_sets(&mut self) -> usize
pub fn count_sets(&mut self) -> usize
Counts the number of unique disjoint sets.
Sourcepub fn group_items(&mut self, items: &[T]) -> Vec<Vec<usize>>
pub fn group_items(&mut self, items: &[T]) -> Vec<Vec<usize>>
Groups items by their containing sets. The result is the indices of items in the provided items
that belongs to different disjoint sets. The order of groups is arbitrary.
Items that do not exist in the forest belongs to the same group that does not consist of other contained items.